@@ -15,7 +15,7 @@ use File::Basename;
 use constant IFS => $/;
 
 our $VERSION;
-$VERSION = "1.10";
+$VERSION = "1.6";
 $VERSION = eval $VERSION;
 
 FILTER {
@@ -389,9 +389,6 @@ sub line_to_text {
         local $/ = IFS;
         my $io = IO::Handle->new();
         my $fn = $file eq '-e' ? "/proc/$$/cmdline" : $file;
-        $fn = $0 unless -e $fn;
-        $fn = "$ENV{PWD}/$0" unless -e $fn;
-        $fn = "$ENV{PWD}/$ENV{_}" unless -e $fn;
         open($io, "$fn") or die "Could not open $file: $!";
         my @source = <$io>;
         $file_cache{$file} = \@source;
@@ -572,19 +569,29 @@ Test::Trivial - Declutter and simplify tests
 
 =head1 SYNOPSIS
 
-    use Test::Trivial tests => 11;
-    
-    OK $expression;
-    NOK $expression;
-    IS $got => $expected;
-    ISNT $got => $expected;
-    ISA $obj => $class;
-    ID $refA => $refB;
-    EQ $numA => $numB;
-    LIKE $got => qr/regex/;
-    UNLIKE $got => qr/regex/;
-    IS ERR { die "OMG No!\n" } => "OMG No!\n";
-    TODO IS $got, $expected;
+use Test::Trivial tests => 11;
+
+OK $expression;
+
+NOK $expression;
+
+IS $got => $expected;
+
+ISNT $got => $expected;
+
+ISA $obj => $class;
+
+ID $refA => $refB;
+
+EQ $numA => $numB;
+
+LIKE $got => qr/regex/;
+
+UNLIKE $got => qr/regex/;
+
+IS ERR { die "OMG No!\n" } => "OMG No!\n";
+
+TODO IS $got, $expected;
 
 =head1 DESCRIPTION
 
